@@ -1,12 +1,13 @@
 import logging
 import os
+import re
 import urllib
 from collections import defaultdict
 from enum import Enum
 from functools import lru_cache
 from pathlib import Path
 from tempfile import NamedTemporaryFile
-from typing import List, cast, Type
+from typing import List, cast, Type, Optional
 
 import requests
 from grobid_client import Client
@@ -27,7 +28,7 @@ from starlette.datastructures import UploadFile
 # _home = os.path.expanduser('~')
 # xdg_cache_home = os.environ.get('XDG_CACHE_HOME') or os.path.join(_home, '.cache')
 APP_GROBID_URI = os.environ.get(
-    "APP_GROBID_URI", "https://entityfishing.kairntech.com/grobid/grobid"
+    "APP_GROBID_URI", "https://entityfishing.kairntech.com/grobid/api"
 )
 
 logger = logging.getLogger("pymultirole")
@@ -56,6 +57,9 @@ class GrobidParameters(ConverterParameters):
     extract_abstract: bool = Field(
         False, description="Do extract an abstract as altText"
     )
+    header_regex: Optional[str] = Field(
+        None, description="Keeps only sections which header name matches the regex", extra="advanced"
+    )
 
 
 class GrobidConverter(ConverterBase):
@@ -200,6 +204,8 @@ def authors_and_affiliations(author_list):
 
 
 def sections_to_text(doc, sections, citations: ArticleCitations, params):
+    header_pattern = re.compile(params.header_regex) if params.header_regex is not None else None
+
     ref2citations = {}
     if params.citations and citations:
         for ref, citation in citations.additional_properties.items():
@@ -209,36 +215,52 @@ def sections_to_text(doc, sections, citations: ArticleCitations, params):
         sentences = []
         annotations = []
         boundaries = defaultdict(list)
+        is_under_matching_header = False
         for section in sections:
-            start = sum(map(len, text_buf))
-            bstart = start
-            text_buf.append((section.name if section.name is not None else "") + "\n")
-            end = sum(map(len, text_buf))
-            sentences.append(Sentence(start=start, end=end))
-            if section.paragraphs:
-                for paragraph in section.paragraphs:
-                    if params.sentences:
-                        for i, sentence in enumerate(paragraph):
+            header_is_not_empty = len(section.paragraphs) > 0
+            header_match = header_pattern is None
+            if header_pattern is not None:
+                if header_pattern.match(section.name):
+                    header_match = True
+                    is_under_matching_header = True
+                else:
+                    if is_under_matching_header and header_is_not_empty:
+                        header_match = True
+                    else:
+                        header_match = False
+                        is_under_matching_header = False
+
+            if header_match:
+                start = sum(map(len, text_buf))
+                bstart = start
+                text_buf.append((section.name if section.name is not None else "") + "\n")
+                end = sum(map(len, text_buf))
+                sentences.append(Sentence(start=start, end=end))
+                if section.paragraphs:
+                    for paragraph in section.paragraphs:
+                        if params.sentences:
+                            for i, sentence in enumerate(paragraph):
+                                sent, annots = add_references(
+                                    sentence, text_buf, ref2citations
+                                )
+                                sentences.append(sent)
+                                if params.citations:
+                                    annotations.extend(annots)
+                                if i < len(paragraph) - 1:
+                                    text_buf.append(" ")
+                            text_buf.append("\n")
+                        else:
                             sent, annots = add_references(
-                                sentence, text_buf, ref2citations
+                                paragraph, text_buf, ref2citations
                             )
                             sentences.append(sent)
                             if params.citations:
                                 annotations.extend(annots)
-                            if i < len(paragraph) - 1:
-                                text_buf.append(" ")
-                        text_buf.append("\n")
-                    else:
-                        sent, annots = add_references(
-                            paragraph, text_buf, ref2citations
-                        )
-                        sentences.append(sent)
-                        if params.citations:
-                            annotations.extend(annots)
-                        text_buf.append("\n")
-            text_buf.append("\n")
-            bend = sum(map(len, text_buf))
-            boundaries[section.name].append(Boundary(start=bstart, end=bend))
+                            text_buf.append("\n")
+                text_buf.append("\n")
+                bend = sum(map(len, text_buf))
+                boundaries[section.name].append(Boundary(start=bstart, end=bend))
+
         doc.text = "".join(text_buf)
         if params.citations:
             doc.annotations = annotations
